@@ -52,6 +52,7 @@
 #include <sys/types.h>
 #include <syslog.h>
 #include <unistd.h>
+#include <grp.h>
 
 #ifdef TIME_WITH_SYS_TIME
 # include <sys/time.h>
@@ -264,12 +265,14 @@ int main(int argc, char *argv[])
         std::vector<std::string> args;
         std::copy(tok.begin(), tok.end(), back_inserter(args));
 
+#if defined(DEBUG) && DEBUG
         for (std::vector<std::string>::iterator iter= args.begin();
              iter != args.end();
              ++iter)
         {
           std::cerr << *iter << std::endl;
         }
+#endif
 
         // Parse the file and store the options
         store(boost::program_options::command_line_parser(args).options(visible).run(), vm);
@@ -504,7 +507,9 @@ static bool _switch_user(const char *user)
       return EXIT_FAILURE;
     }
 
-    if (setgid(pw->pw_gid) == -1 || setuid(pw->pw_uid) == -1)
+    if (setgroups(0, NULL) == -1 ||
+        setgid(pw->pw_gid) == -1 ||
+        setuid(pw->pw_uid) == -1)
     {
       error::message("Could not switch to user", user);
       return EXIT_FAILURE;
