@@ -113,6 +113,9 @@ const char* gearmand_io_st::port() const
   return "-";
 }
 
+#if __GNUC__ >= 7
+  #pragma GCC diagnostic warning "-Wimplicit-fallthrough"
+#endif
 static size_t _connection_read(gearman_server_con_st *con, void *data, size_t data_size, gearmand_error_t &ret)
 {
   ssize_t read_size;
@@ -149,20 +152,20 @@ static size_t _connection_read(gearman_server_con_st *con, void *data, size_t da
           break;
 
         case SSL_ERROR_SYSCALL:
-
           if (errno) // If errno is really set, then let our normal error logic handle.
           {
             read_size= SOCKET_ERROR;
             break;
           }
+          /* fall-thru */
 
         case SSL_ERROR_SSL:
         default:
           { // All other errors
-            char errorString[SSL_ERROR_SIZE];
+            char errorString[SSL_ERROR_SIZE]= { 0 };
             ERR_error_string_n(ssl_error, errorString, sizeof(errorString));
             ret= GEARMAND_LOST_CONNECTION;
-            gearmand_log_info(GEARMAN_DEFAULT_LOG_PARAM, "SSL failure(%s) errno:%d", errorString);
+            gearmand_log_info(GEARMAN_DEFAULT_LOG_PARAM, "SSL failure(%s) errno:%d", errorString, errno);
             _connection_close(connection);
 
             return 0;
@@ -334,11 +337,12 @@ static gearmand_error_t _connection_flush(gearman_server_con_st *con)
                 write_size= SOCKET_ERROR;
                 break;
               }
-
+              /* fall-thru */
+              
             case SSL_ERROR_SSL:
             default:
               {
-                char errorString[SSL_ERROR_SIZE];
+                char errorString[SSL_ERROR_SIZE]= { 0 };
                 ERR_error_string_n(ssl_error, errorString, sizeof(errorString));
                 _connection_close(connection);
                 return gearmand_log_gerror(GEARMAN_DEFAULT_LOG_PARAM, GEARMAND_LOST_CONNECTION, "SSL failure(%s)",
@@ -572,6 +576,9 @@ gearmand_con_st *gearman_io_context(const gearmand_io_st *connection)
   return connection->context;
 }
 
+#if __GNUC__ >= 7
+  #pragma GCC diagnostic warning "-Wimplicit-fallthrough"
+#endif
 gearmand_error_t gearman_io_send(gearman_server_con_st *con,
                                  const gearmand_packet_st *packet, bool flush)
 {
@@ -662,6 +669,7 @@ gearmand_error_t gearman_io_send(gearman_server_con_st *con,
 
     /* Flush buffer now so we can start writing directly from data buffer. */
     connection->send_state= gearmand_io_st::GEARMAND_CON_SEND_UNIVERSAL_FORCE_FLUSH;
+    /* fall-thru */
 
   case gearmand_io_st::GEARMAND_CON_SEND_UNIVERSAL_FORCE_FLUSH:
     {
@@ -670,6 +678,7 @@ gearmand_error_t gearman_io_send(gearman_server_con_st *con,
       {
         return local_ret;
       }
+      /* fall-thru */
     }
 
     connection->send_data_size= packet->data_size;
@@ -695,6 +704,7 @@ gearmand_error_t gearman_io_send(gearman_server_con_st *con,
 
     connection->send_buffer_ptr= const_cast<char *>(packet->data) + connection->send_data_offset;
     connection->send_state= gearmand_io_st::GEARMAND_CON_SEND_UNIVERSAL_FLUSH_DATA;
+    /* fall-thru */
 
   case gearmand_io_st::GEARMAND_CON_SEND_UNIVERSAL_FLUSH:
   case gearmand_io_st::GEARMAND_CON_SEND_UNIVERSAL_FLUSH_DATA:
@@ -710,6 +720,7 @@ gearmand_error_t gearman_io_send(gearman_server_con_st *con,
       return local_ret;
     }
   }
+  /* fall-thru */
 
   if (flush)
   {
@@ -749,6 +760,7 @@ gearmand_error_t gearman_io_recv(gearman_server_con_st *con, bool recv_data)
     connection->recv_packet->reset(GEARMAN_MAGIC_TEXT, GEARMAN_COMMAND_TEXT);
 
     connection->recv_state= gearmand_io_st::GEARMAND_CON_RECV_UNIVERSAL_READ;
+    /* fall-thru */
 
   case gearmand_io_st::GEARMAND_CON_RECV_UNIVERSAL_READ:
     while (1)
@@ -784,7 +796,7 @@ gearmand_error_t gearman_io_recv(gearman_server_con_st *con, bool recv_data)
       connection->recv_buffer_ptr= connection->recv_buffer;
 
       size_t recv_size= _connection_read(con, connection->recv_buffer + connection->recv_buffer_size,
-					 GEARMAND_RECV_BUFFER_SIZE - connection->recv_buffer_size, ret);
+                                         GEARMAND_RECV_BUFFER_SIZE - connection->recv_buffer_size, ret);
       if (gearmand_failed(ret))
       {
         // GEARMAND_LOST_CONNECTION is not worth a warning, clients/workers just
@@ -827,6 +839,7 @@ gearmand_error_t gearman_io_recv(gearman_server_con_st *con, bool recv_data)
 
     packet->options.free_data= true;
     connection->recv_state= gearmand_io_st::GEARMAND_CON_RECV_STATE_READ_DATA;
+    /* fall-thru */
 
   case gearmand_io_st::GEARMAND_CON_RECV_STATE_READ_DATA:
     while (connection->recv_data_size)
